package com.ccwangluo.accelerator.utils

import android.content.Context
import androidx.lifecycle.lifecycleScope
import com.ccwangluo.accelerator.model.BaseModel
import com.ccwangluo.accelerator.model.LoginRes
import com.ccwangluo.accelerator.utils.http.HttpGo
import com.ccwangluo.cc_quickly.ui.login.PhoneLoginFragment
import com.tencent.mmkv.MMKV
import com.xuexiang.xpage.base.XPageFragment
import com.xuexiang.xpage.core.PageOption
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch

object LoginUtils {

    fun login(xPageFragment: XPageFragment){
        PhoneUtils.openLoginAuth(xPageFragment) { b, s ->
            if (b) {
                val map = mutableMapOf<String, String>()
                map.put("token", s)
                xPageFragment.lifecycleScope.launch(Dispatchers.IO) {
                    val res = HttpGo.postSync<BaseModel<LoginRes>>("/user/flash/login", map)
                    res?.let {
                        println(it)
                    }
                }
            } else {
                PageOption.to(PhoneLoginFragment::class.java).open(xPageFragment)
            }
        }
    }

    private var sToken: String? = null
    private const val KEY_TOKEN = "com.ccwangluo.KEY_TOKEN"

    /**
     * 初始化Token信息
     */
    fun init(context: Context?) {
        sToken = MMKV.defaultMMKV().decodeString(KEY_TOKEN, "")
    }

    fun clearToken() {
        sToken = null
        MMKV.defaultMMKV().remove(KEY_TOKEN)
    }

    var token: String?
        get() = sToken
        set(token) {
            sToken = token
            MMKV.defaultMMKV().putString(KEY_TOKEN, token)
        }

    fun hasToken(): Boolean {
        return MMKV.defaultMMKV().containsKey(KEY_TOKEN)
    }

}